@@ -497,7 +497,7 @@ static int p_ai_calc_score(pfield *f, fallout *b, airule_int *a, int *next, int
 }
 
 
-static void p_ai_align(pfield *f, airule_int *a, int *blocks, int *next, int fieldwidth, int mintomatch) {
+static void p_ai_align(pfield *f, airule_int *a, int *blocks, int *next, int mintomatch, int numcolors) {
 /* p_ai_align
 
    Runs all scores for all possible moves, and decides which move is the
@@ -508,7 +508,7 @@ static void p_ai_align(pfield *f, airule_int *a, int *blocks, int *next, int fie
    horizontally.  */
 
    fallout b;                             /* Fallout (see above) */
-   int scores[fieldwidth * 4 - 2];        /* Listing of scores */
+   int scores[f->width * 4 - 2];          /* Listing of scores */
    int *scorep;                           /* Pointer into above */
    int scoremax;                          /* Maximum score seen */
    int match;                             /* Set when a move is finally selected */
@@ -522,7 +522,7 @@ static void p_ai_align(pfield *f, airule_int *a, int *blocks, int *next, int fie
       moves */
    scorep = scores;
    scoremax = -9999;
-   for(i = 0; i < fieldwidth; i++) {
+   for(i = 0; i < f->width; i++) {
       p_ai_set_blocks(&b, i, 0, blocks[1], i, 1, blocks[0]);
       p_ai_drop_blocks(f, &b);
       *scorep = p_ai_calc_score(f, &b, a, next, mintomatch);
@@ -535,7 +535,7 @@ static void p_ai_align(pfield *f, airule_int *a, int *blocks, int *next, int fie
       scorep++;
 
       /* Are there any horizontal blocks here? */
-      if(i < fieldwidth - 1) {
+      if(i < f->width - 1) {
          p_ai_set_blocks(&b, i, 0, blocks[0], i + 1, 0, blocks[1]);
          p_ai_drop_blocks(f, &b);
          *scorep = p_ai_calc_score(f, &b, a, next, mintomatch);
@@ -552,7 +552,7 @@ static void p_ai_align(pfield *f, airule_int *a, int *blocks, int *next, int fie
    /* Select a random choice with the maximum score (must be at least one!) */
    match = 0;
    while(!match) {
-      i = rand() % (fieldwidth * 4 - 2);
+      i = rand() % (f->width * 4 - 2);
       if(scores[i] == scoremax) match = 1;
    }
    a->score = scores[i];
@@ -575,12 +575,12 @@ static void p_ai_align(pfield *f, airule_int *a, int *blocks, int *next, int fie
 }
 
 
-void p_ai_decide(pfield *f, airule *a, int *cur, int *next, int fieldwidth, int mintomatch) {
+void p_ai_decide(pfield *f, airule *a, int *cur, int *next, int mintomatch, int numcolors) {
 /* p_ai_decide
 
    Interface to above function */
 
-   p_ai_align(f, (airule_int *)a, cur, next, fieldwidth, mintomatch);
+   p_ai_align(f, (airule_int *)a, cur, next, mintomatch, numcolors);
    return;
 
 }
