@@ -77,6 +77,10 @@
 #define P_CONFIG_INSANITY           0x600       /* Insanity */
 
 #define P_CONFIG_HQMIXER            0x800       /* Use HQ mixer in sound? */
+#define P_CONFIG_EFFECTS            0x801       /* Use effects in sound? */
+
+#define P_CONFIG_TOOLTIPS           0xA00       /* Display tooltips if set */
+#define P_CONFIG_QUIET              0xA01       /* Be quiet if set */
 
 
 /* The full list of supported long options */
@@ -101,12 +105,18 @@ static const struct option longopt[] =
    {  "norestart", 0, 0, P_CONFIG_NO('t') },
    {  "tutorial",  0, 0, 'T' },
    {  "notutorial",  0, 0, P_CONFIG_NO('T') },
+   {  "tooltips", 0, 0, P_CONFIG_TOOLTIPS },
+   {  "notooltips", 0, 0, P_CONFIG_NO(P_CONFIG_TOOLTIPS) },
+   {  "quiet", 0, 0, P_CONFIG_QUIET },
+   {  "noquiet", 0, 0, P_CONFIG_NO(P_CONFIG_QUIET) },
 
    /* Sound options */
    {  "sound",  0, 0, 'S' },
    {  "nosound", 0, 0, P_CONFIG_NO('S') },
    {  "hqmixer", 0, 0, P_CONFIG_HQMIXER },
    {  "nohqmixer", 0, 0, P_CONFIG_NO(P_CONFIG_HQMIXER) },
+   {  "effects", 0, 0, P_CONFIG_EFFECTS },
+   {  "noeffects", 0, 0, P_CONFIG_NO(P_CONFIG_EFFECTS) },
 
    /* Advanced options */
    {  "width", 1, 0, P_CONFIG_WIDTH },
@@ -254,9 +264,11 @@ static void p_config_load(pconfig *c, int *ai1, int *ai2) {
          else if(!strcmp(buf, "restart"))          c->restart = atoi(p);
          else if(!strcmp(buf, "tutorial"))         c->tutorial = atoi(p);
          else if(!strcmp(buf, "quiet"))            c->quiet = atoi(p);
+         else if(!strcmp(buf, "tooltips"))         c->tooltips = atoi(p);
          #if USE_SOUND
             else if(!strcmp(buf, "enablesound"))      c->enablesound = atoi(p);
             else if(!strcmp(buf, "usehqmixer"))       c->usehqmixer = atoi(p);
+            else if(!strcmp(buf, "useeffects"))       c->useeffects = atoi(p);
          #endif /* SOUND? */
          else if(!strcmp(buf, "theme"))            p_strncpy(c->theme, p, P_THEME_NAME_SIZE);
          else if(!strcmp(buf, "ai1")) {
@@ -305,10 +317,12 @@ void p_config_save(const pconfig *c) {
    fprintf(f, "restart=%d\n",                c->restart);
    fprintf(f, "tutorial=%d\n",               c->tutorial);
    fprintf(f, "quiet=%d\n",                  c->quiet);
+   fprintf(f, "tooltips=%d\n",               c->tooltips);
    fprintf(f, "theme=%s\n",                  c->theme);
    #if USE_SOUND
       fprintf(f, "enablesound=%d\n",            c->enablesound);
       fprintf(f, "usehqmixer=%d\n",             c->usehqmixer);
+      fprintf(f, "useeffects=%d\n",             c->useeffects);
    #endif /* Sound? */
    fprintf(f, "ai1=%d\n",                    P_PLAYER_0(c)->airule);
    fprintf(f, "ai2=%d\n",                    P_PLAYER_1(c)->airule);
@@ -349,6 +363,7 @@ static void p_config_init(pconfig *c, int *airule1, int *airule2) {
       c->hypertournament = false;
    #endif
    c->quiet = false;
+   c->tooltips = true;
    c->nodisplay = false;
    c->needredraw = true;
    
@@ -356,6 +371,7 @@ static void p_config_init(pconfig *c, int *airule1, int *airule2) {
       c->sound = NULL;
       c->enablesound = true;
       c->usehqmixer = false;
+      c->useeffects = true;
    #endif /* Sound setup? */
 
    /* Set default AI rules */
@@ -478,6 +494,12 @@ pconfig *p_config_new(int *argc, char ***argv) {
       case 'T':
          c->tutorial = !isinvert(&inv);
          break;
+      case P_CONFIG_TOOLTIPS:
+         c->tooltips = !isinvert(&inv);
+         break;
+      case P_CONFIG_QUIET:
+         c->quiet = !isinvert(&inv);
+         break;
 
       /* Sound options */
       #if USE_SOUND
@@ -487,6 +509,9 @@ pconfig *p_config_new(int *argc, char ***argv) {
          case P_CONFIG_HQMIXER:
             c->usehqmixer = !isinvert(&inv);
             break;
+         case P_CONFIG_EFFECTS:
+            c->useeffects = !isinvert(&inv);
+            break;
       #endif /* Sound? */
 
       /* Advanced options */
@@ -715,7 +740,7 @@ pconfig *p_config_new(int *argc, char ***argv) {
    /* Setup sound service? */
    #if USE_SOUND
       p_sound_init();
-      c->sound = p_sound_new(c->enablesound, c->usehqmixer);
+      c->sound = p_sound_new(c->enablesound, c->usehqmixer, c->useeffects);
    #endif /* Sound allowed? */
    
    /* Initialise game */
